@@ -19,25 +19,26 @@ use Getopt::Long qw(GetOptions);
 use Pod::Usage qw(pod2usage);
 use Storable;
 
-use lib dirname($0) . '/lib';
-use lib dirname(dirname($0)) . '/lib';
-use lib dirname(dirname($0)) . '/build/lib';
-use lib dirname(dirname($0)) . '/test/lib';
+use lib dirname(abs_path($0)) . '/lib';
+use lib dirname(dirname(abs_path($0))) . '/lib';
+use lib dirname(dirname(abs_path($0))) . '/build/lib';
+use lib dirname(dirname(abs_path($0))) . '/test/lib';
 
-use BackRestDoc::Common::Doc;
-use BackRestDoc::Common::DocConfig;
-use BackRestDoc::Common::DocManifest;
-use BackRestDoc::Common::DocRender;
-use BackRestDoc::Html::DocHtmlSite;
-use BackRestDoc::Latex::DocLatex;
-use BackRestDoc::Markdown::DocMarkdown;
+use pgBackRestTest::Common::ExecuteTest;
+use pgBackRestTest::Common::Storage;
+use pgBackRestTest::Common::StoragePosix;
 
-use pgBackRest::Common::Exception;
-use pgBackRest::Common::Log;
-use pgBackRest::Common::String;
-use pgBackRest::Storage::Local;
-use pgBackRest::Storage::Posix::Driver;
-use pgBackRest::Version;
+use pgBackRestDoc::Common::Doc;
+use pgBackRestDoc::Common::DocConfig;
+use pgBackRestDoc::Common::DocManifest;
+use pgBackRestDoc::Common::DocRender;
+use pgBackRestDoc::Common::Exception;
+use pgBackRestDoc::Common::Log;
+use pgBackRestDoc::Common::String;
+use pgBackRestDoc::Html::DocHtmlSite;
+use pgBackRestDoc::Latex::DocLatex;
+use pgBackRestDoc::Markdown::DocMarkdown;
+use pgBackRestDoc::ProjectInfo;
 
 ####################################################################################################################################
 # Usage
@@ -60,19 +61,19 @@ doc.pl [options]
    --no-exe         Should commands be executed when building help? (for testing only)
    --no-cache       Don't use execution cache
    --cache-only     Only use the execution cache - don't attempt to generate it
-   --var            Override variables defined in the XML
+   --pre            Pre-build containers for execute elements marked pre
+   --var            Override defined variable
+   --key-var        Override defined variable and use in cache key
    --doc-path       Document path to render (manifest.xml should be located here)
    --out            Output types (html, pdf, markdown)
+   --out-preserve   Don't clean output directory
    --require        Require only certain sections of the document (to speed testing)
    --include        Include source in generation (links will reference website)
    --exclude        Exclude source from generation (links will reference website)
 
-Keyword Options:
-   --keyword        Keyword used to filter output
-   --keyword-add    Add keyword without overriding 'default' keyword
-   --dev            Add 'dev' keyword
-   --debug          Add 'debug' keyword
-   --pre            Add 'pre' keyword
+ Variable Options:
+   --dev            Set 'dev' variable to 'y'
+   --debug          Set 'debug' variable to 'y'
 =cut
 
 ####################################################################################################################################
@@ -85,11 +86,11 @@ my $strLogLevel = 'info';
 my $bNoExe = false;
 my $bNoCache = false;
 my $bCacheOnly = false;
-my $oVariableOverride = {};
+my $rhVariableOverride = {};
+my $rhKeyVariableOverride = {};
 my $strDocPath;
 my @stryOutput;
-my @stryKeyword;
-my @stryKeywordAdd;
+my $bOutPreserve = false;
 my @stryRequire;
 my @stryInclude;
 my @stryExclude;
@@ -103,8 +104,7 @@ GetOptions ('help' => \$bHelp,
             'quiet' => \$bQuiet,
             'log-level=s' => \$strLogLevel,
             'out=s@' => \@stryOutput,
-            'keyword=s@' => \@stryKeyword,
-            'keyword-add=s@' => \@stryKeywordAdd,
+            'out-preserve' => \$bOutPreserve,
             'require=s@' => \@stryRequire,
             'include=s@' => \@stryInclude,
             'exclude=s@' => \@stryExclude,
@@ -115,7 +115,8 @@ GetOptions ('help' => \$bHelp,
             'debug', \$bDebug,
             'pre', \$bPre,
             'cache-only', \$bCacheOnly,
-            'var=s%', $oVariableOverride,
+            'key-var=s%', $rhKeyVariableOverride,
+            'var=s%', $rhVariableOverride,
             'doc-path=s', \$strDocPath)
     or pod2usage(2);
 
@@ -127,7 +128,7 @@ eval
     # Display version and exit if requested
     if ($bHelp || $bVersion)
     {
-        print BACKREST_NAME . ' ' . BACKREST_VERSION . " Documentation Builder\n";
+        print PROJECT_NAME . ' ' . PROJECT_VERSION . " Documentation Builder\n";
 
         if ($bHelp)
         {
@@ -168,31 +169,16 @@ eval
         $strLogLevel = 'error';
     }
 
-    # If no keyword was passed then use default
-    if (@stryKeyword == 0)
-    {
-        @stryKeyword = ('default');
-    }
-
-    # Push added keywords
-    push(@stryKeyword, @stryKeywordAdd);
-
-    # If --dev passed then add the dev keyword
+    # If --dev passed then set the dev var to 'y'
     if ($bDev)
     {
-        push(@stryKeyword, 'dev');
+        $rhVariableOverride->{'dev'} = 'y';
     }
 
-    # If --debug passed then add the debug keyword
+    # If --debug passed then set the debug var to 'y'
     if ($bDebug)
     {
-        push(@stryKeyword, 'debug');
-    }
-
-    # If --pre passed then add the pre keyword
-    if ($bPre)
-    {
-        push(@stryKeyword, 'pre');
+        $rhVariableOverride->{'debug'} = 'y';
     }
 
     # Doesn't make sense to pass include and exclude
@@ -206,8 +192,8 @@ eval
     # Get the base path
     my $strBasePath = abs_path(dirname($0));
 
-    my $oStorageDoc = new pgBackRest::Storage::Local(
-        $strBasePath, new pgBackRest::Storage::Posix::Driver({bFileSync => false, bPathSync => false}));
+    my $oStorageDoc = new pgBackRestTest::Common::Storage(
+        $strBasePath, new pgBackRestTest::Common::StoragePosix({bFileSync => false, bPathSync => false}));
 
     if (!defined($strDocPath))
     {
@@ -223,10 +209,39 @@ eval
             or confess &log(ERROR, "unable to create path ${strOutputPath}");
     }
 
+    # Merge key variables into the variable list and ensure there are no duplicates
+    foreach my $strKey (sort(keys(%{$rhKeyVariableOverride})))
+    {
+        if (defined($rhVariableOverride->{$strKey}))
+        {
+            confess &log(ERROR, "'${strKey}' cannot be passed as --var and --key-var");
+        }
+
+        $rhVariableOverride->{$strKey} = $rhKeyVariableOverride->{$strKey};
+    }
+
+    # Build C code
+    my $strBuildPath = "${strBasePath}/output/build";
+    my $strRepoPath = dirname($strBasePath);
+    my $strBuildNinja = "${strBuildPath}/build.ninja";
+
+    &log(INFO, "build C helper");
+
+    if (!-e $strBuildNinja)
+    {
+        executeTest("meson setup -Dwerror=true -Dfatal-errors=true -Dbuildtype=debug ${strBuildPath} ${strRepoPath}");
+    }
+
+    executeTest("ninja -C ${strBuildPath} doc/src/doc-pgbackrest");
+    executeTest(
+        "${strBuildPath}/doc/src/doc-pgbackrest --repo-path=${strRepoPath}" .
+            ($strLogLevel ne 'info' ? " --log-level=${strLogLevel}" : ''),
+        {bShowOutputAsync => true});
+
     # Load the manifest
-    my $oManifest = new BackRestDoc::Common::DocManifest(
-        $oStorageDoc, \@stryKeyword, \@stryRequire, \@stryInclude, \@stryExclude, $oVariableOverride, $strDocPath, $bDeploy,
-        $bCacheOnly);
+    my $oManifest = new pgBackRestDoc::Common::DocManifest(
+        $oStorageDoc, \@stryRequire, \@stryInclude, \@stryExclude, $rhKeyVariableOverride, $rhVariableOverride,
+        $strDocPath, $bDeploy, $bCacheOnly, $bPre);
 
     if (!$bNoCache)
     {
@@ -240,24 +255,71 @@ eval
 
         if ($oManifest->isBackRest())
         {
-            push(@stryOutput, 'help');
             push(@stryOutput, 'man');
         }
     }
 
+    # Build host containers
+    if (!$bCacheOnly && !$bNoExe)
+    {
+        foreach my $strSource ($oManifest->sourceList())
+        {
+            if ((@stryInclude == 0 || grep(/$strSource/, @stryInclude)) && !grep(/$strSource/, @stryExclude))
+            {
+                &log(INFO, "source $strSource");
+
+                foreach my $oHostDefine ($oManifest->sourceGet($strSource)->{doc}->nodeList('host-define', false))
+                {
+                    if ($oManifest->evaluateIf($oHostDefine))
+                    {
+                        my $strImage = $oManifest->variableReplace($oHostDefine->paramGet('image'));
+                        my $strFrom = $oManifest->variableReplace($oHostDefine->paramGet('from'));
+                        my $strDockerfile = "${strOutputPath}/doc-host.dockerfile";
+
+                        &log(INFO, "Build vm '${strImage}' from '${strFrom}'");
+
+                        $oStorageDoc->put(
+                            $strDockerfile,
+                            "FROM ${strFrom}\n\n" . trim($oManifest->variableReplace($oHostDefine->valueGet())) . "\n");
+                        executeTest("docker build -f ${strDockerfile} -t ${strImage} ${strBasePath}", {bSuppressStdErr => true});
+                    }
+                }
+            }
+        }
+    }
+
+    # Render output
     for my $strOutput (@stryOutput)
     {
-        if (!(($strOutput eq 'help' || $strOutput eq 'man') && $oManifest->isBackRest()))
+        &log(INFO, "render ${strOutput} output");
+
+        # Man output has already been generated in C so do not remove it
+        next if ($strOutput eq 'man');
+
+        # Clean contents of out directory
+        if (!$bOutPreserve)
         {
-            $oManifest->renderGet($strOutput);
+            my $strOutputPath = $strOutput eq 'pdf' ? "${strOutputPath}/latex" : "${strOutputPath}/$strOutput";
+
+            # Clean the current out path if it exists
+            if (-e $strOutputPath)
+            {
+                executeTest("rm -rf ${strOutputPath}/*");
+            }
+            # Else create the html path
+            else
+            {
+                mkdir($strOutputPath)
+                    or confess &log(ERROR, "unable to create path ${strOutputPath}");
+            }
         }
 
-        &log(INFO, "render ${strOutput} output");
+        $oManifest->renderGet($strOutput);
 
         if ($strOutput eq 'markdown')
         {
             my $oMarkdown =
-                new BackRestDoc::Markdown::DocMarkdown
+                new pgBackRestDoc::Markdown::DocMarkdown
                 (
                     $oManifest,
                     "${strBasePath}/xml",
@@ -267,29 +329,10 @@ eval
 
             $oMarkdown->process();
         }
-        elsif (($strOutput eq 'help' || $strOutput eq 'man') && $oManifest->isBackRest())
-        {
-            # Generate the command-line help
-            my $oRender = new BackRestDoc::Common::DocRender('text', $oManifest, !$bNoExe);
-            my $oDocConfig =
-                new BackRestDoc::Common::DocConfig(
-                    new BackRestDoc::Common::Doc("${strBasePath}/xml/reference.xml"), $oRender);
-
-            if ($strOutput eq 'help')
-            {
-                $oDocConfig->helpDataWrite($oManifest);
-            }
-            else
-            {
-                $oStorageDoc->pathCreate(
-                    "${strBasePath}/output/man", {strMode => '0770', bIgnoreExists => true, bCreateParent => true});
-                $oStorageDoc->put("${strBasePath}/output/man/" . lc(BACKREST_NAME) . '.1.txt', $oDocConfig->manGet($oManifest));
-            }
-        }
         elsif ($strOutput eq 'html')
         {
             my $oHtmlSite =
-                new BackRestDoc::Html::DocHtmlSite
+                new pgBackRestDoc::Html::DocHtmlSite
                 (
                     $oManifest,
                     "${strBasePath}/xml",
@@ -307,7 +350,7 @@ eval
         elsif ($strOutput eq 'pdf')
         {
             my $oLatex =
-                new BackRestDoc::Latex::DocLatex
+                new pgBackRestDoc::Latex::DocLatex
                 (
                     $oManifest,
                     "${strBasePath}/xml",
