@@ -6,6 +6,7 @@ Expire Command
 #include "command/archive/common.h"
 #include "command/backup/common.h"
 #include "command/control/common.h"
+#include "command/expire/expire.h"
 #include "common/debug.h"
 #include "common/regExp.h"
 #include "common/time.h"
@@ -98,7 +99,7 @@ expireAdhocBackup(InfoBackup *const infoBackup, const String *const backupLabel,
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(INFO_BACKUP, infoBackup);
         FUNCTION_LOG_PARAM(STRING, backupLabel);
-        FUNCTION_TEST_PARAM(UINT, repoIdx);
+        FUNCTION_LOG_PARAM(UINT, repoIdx);
     FUNCTION_LOG_END();
 
     ASSERT(infoBackup != NULL);
@@ -448,7 +449,7 @@ removeExpiredArchive(const InfoBackup *const infoBackup, const bool timeBasedFul
                     cfgOptionIdxStrNull(cfgOptRepoCipherPass, repoIdx));
                 const InfoPg *const infoArchivePgData = infoArchivePg(infoArchive);
 
-                // Get a list of archive directories (e.g. 9.4-1, 10-2, etc) sorted by the db-id (number after the dash).
+                // Get a list of archive directories (e.g. 9.6-1, 10-2, etc) sorted by the db-id (number after the dash).
                 const StringList *const listArchiveDisk = strLstSort(
                     strLstComparatorSet(
                         storageListP(
@@ -506,7 +507,7 @@ removeExpiredArchive(const InfoBackup *const infoBackup, const bool timeBasedFul
                         const unsigned int archivePgId = cvtZToUInt(strrchr(strZ(archiveId), '-') + 1);
 
                         // From the global list of backups to retain, create a list of backups, oldest to newest, associated with
-                        // this archiveId (e.g. 9.4-1), e.g. If globalBackupRetention has 4F, 3F, 2F, 1F then
+                        // this archiveId (e.g. 9.6-1), e.g. If globalBackupRetention has 4F, 3F, 2F, 1F then
                         // localBackupRetentionList will have 1F, 2F, 3F, 4F (assuming they all have same history id)
                         for (unsigned int retentionIdx = strLstSize(globalBackupRetentionList) - 1;
                              (int)retentionIdx >= 0; retentionIdx--)
@@ -676,9 +677,16 @@ removeExpiredArchive(const InfoBackup *const infoBackup, const bool timeBasedFul
                                             .recurse = true);
                                     }
 
+                                    LOG_DETAIL_FMT(
+                                        "%s: %s remove archive path %s", cfgOptionGroupName(cfgOptGrpRepo, repoIdx),
+                                        strZ(archiveId), strZ(walPath));
+
                                     archiveExpire.total++;
-                                    archiveExpire.start = strDup(walPath);
                                     archiveExpire.stop = strDup(walPath);
+
+                                    // Update start for the first WAL path removed
+                                    if (archiveExpire.start == NULL)
+                                        archiveExpire.start = strDup(walPath);
                                 }
                                 // Else delete individual files instead if the major path is less than or equal to the most recent
                                 // retention backup. This optimization prevents scanning though major paths that could not possibly
@@ -976,9 +984,6 @@ cmdExpire(void)
 {
     FUNCTION_LOG_VOID(logLevelDebug);
 
-    // Verify the repo is local
-    repoIsLocalVerify();
-
     // Test for stop file
     lockStopTest();
 
