@@ -4,6 +4,7 @@ Stanza Commands Handler
 #include "build.auto.h"
 
 #include "command/check/common.h"
+#include "command/stanza/common.h"
 #include "common/debug.h"
 #include "common/log.h"
 #include "config/config.h"
@@ -47,7 +48,7 @@ pgValidate(void)
         if (cfgOptionBool(cfgOptOnline))
         {
             // Check the primary connections (and standby, if any) and return the primary database object.
-            const DbGetResult dbObject = dbGet(false, true, false);
+            const DbGetResult dbObject = dbGet(false, true, CFGOPTVAL_BACKUP_STANDBY_N);
 
             // Get the pgControl information from the pg*-path deemed to be the primary
             result = dbPgControl(dbObject.primary);
