@@ -3,8 +3,6 @@ LZ4 Compress
 
 Compress IO to the lz4 format.
 ***********************************************************************************************************************************/
-#ifdef HAVE_LIBLZ4
-
 #ifndef COMMON_COMPRESS_LZ4_COMPRESS_H
 #define COMMON_COMPRESS_LZ4_COMPRESS_H
 
@@ -28,5 +26,3 @@ Constructors
 FN_EXTERN IoFilter *lz4CompressNew(int level, bool raw);
 
 #endif
-
-#endif // HAVE_LIBLZ4
