@@ -16,11 +16,9 @@ Object type
 struct List
 {
     ListPub pub;                                                    // Publicly accessible variables
-    size_t itemSize;
     unsigned int listSizeMax;
     SortOrder sortOrder;
     unsigned char *listAlloc;                                       // Pointer to memory allocated for the list
-    unsigned char *list;                                            // Pointer to the current start of the list
     ListComparator *comparator;
 };
 
@@ -37,7 +35,10 @@ lstNew(const size_t itemSize, const ListParam param)
     {
         *this = (List)
         {
-            .itemSize = itemSize,
+            .pub =
+            {
+                .itemSize = itemSize,
+            },
             .sortOrder = param.sortOrder,
             .comparator = param.comparator,
         };
@@ -57,11 +58,11 @@ lstClear(List *const this)
 
     ASSERT(this != NULL);
 
-    if (this->list != NULL)
+    if (this->pub.list != NULL)
     {
         MEM_CONTEXT_BEGIN(lstMemContext(this))
         {
-            memFree(this->list);
+            memFree(this->pub.list);
         }
         MEM_CONTEXT_END();
 
@@ -84,7 +85,25 @@ lstComparatorStr(const void *const item1, const void *const item2)
     ASSERT(item1 != NULL);
     ASSERT(item2 != NULL);
 
-    FUNCTION_TEST_RETURN(INT, strCmp(*(String **)item1, *(String **)item2));
+    FUNCTION_TEST_RETURN(INT, strCmp(*(const String *const *)item1, *(const String *const *)item2));
+}
+
+/**********************************************************************************************************************************/
+FN_EXTERN int
+lstComparatorInt(const void *const intPtr1, const void *const intPtr2)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM_P(VOID, intPtr1);
+        FUNCTION_TEST_PARAM_P(VOID, intPtr2);
+    FUNCTION_TEST_END();
+
+    ASSERT(intPtr1 != NULL);
+    ASSERT(intPtr2 != NULL);
+
+    const int int1 = *(const int *)intPtr1;
+    const int int2 = *(const int *)intPtr2;
+
+    FUNCTION_TEST_RETURN(INT, LST_COMPARATOR_CMP(int1, int2));
 }
 
 /**********************************************************************************************************************************/
@@ -99,8 +118,8 @@ lstComparatorUInt(const void *const uintPtr1, const void *const uintPtr2)
     ASSERT(uintPtr1 != NULL);
     ASSERT(uintPtr2 != NULL);
 
-    const unsigned int uint1 = *(unsigned int *)uintPtr1;
-    const unsigned int uint2 = *(unsigned int *)uintPtr2;
+    const unsigned int uint1 = *(const unsigned int *)uintPtr1;
+    const unsigned int uint2 = *(const unsigned int *)uintPtr2;
 
     FUNCTION_TEST_RETURN(INT, LST_COMPARATOR_CMP(uint1, uint2));
 }
@@ -117,7 +136,7 @@ lstComparatorZ(const void *const item1, const void *const item2)
     ASSERT(item1 != NULL);
     ASSERT(item2 != NULL);
 
-    FUNCTION_TEST_RETURN(INT, strcmp(*(char **)item1, *(char **)item2));
+    FUNCTION_TEST_RETURN(INT, strcmp(*(const char *const *)item1, *(const char *const *)item2));
 }
 
 /***********************************************************************************************************************************
@@ -147,7 +166,7 @@ lstGet(const List *const this, const unsigned int listIdx)
         THROW_FMT(AssertError, "cannot get index %u from list with %u value(s)", listIdx, lstSize(this));
 
     // Return pointer to list item
-    FUNCTION_TEST_RETURN_P(VOID, this->list + (listIdx * this->itemSize));
+    FUNCTION_TEST_RETURN_P(VOID, this->pub.list + (listIdx * this->pub.itemSize));
 }
 
 FN_EXTERN void *
@@ -180,16 +199,16 @@ lstFind(const List *const this, const void *const item)
     ASSERT(this->comparator != NULL);
     ASSERT(item != NULL);
 
-    if (this->list != NULL)
+    if (this->pub.list != NULL)
     {
         if (this->sortOrder == sortOrderAsc)
-            FUNCTION_TEST_RETURN_P(VOID, bsearch(item, this->list, lstSize(this), this->itemSize, this->comparator));
+            FUNCTION_TEST_RETURN_P(VOID, bsearch(item, this->pub.list, lstSize(this), this->pub.itemSize, this->comparator));
         else if (this->sortOrder == sortOrderDesc)
         {
             // Assign the list for the descending comparator to use
             comparatorDescList = this;
 
-            FUNCTION_TEST_RETURN_P(VOID, bsearch(item, this->list, lstSize(this), this->itemSize, lstComparatorDesc));
+            FUNCTION_TEST_RETURN_P(VOID, bsearch(item, this->pub.list, lstSize(this), this->pub.itemSize, lstComparatorDesc));
         }
 
         // Fall back on an iterative search
@@ -219,8 +238,8 @@ lstFindIdx(const List *const this, const void *const item)
     FUNCTION_TEST_RETURN(UINT, result == NULL ? LIST_NOT_FOUND : lstIdx(this, result));
 }
 
-FN_EXTERN void *
-lstFindDefault(const List *const this, const void *const item, void *const itemDefault)
+FN_EXTERN const void *
+lstFindDefault(const List *const this, const void *const item, const void *const itemDefault)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(LIST, this);
@@ -233,7 +252,7 @@ lstFindDefault(const List *const this, const void *const item, void *const itemD
 
     void *const result = lstFind(this, item);
 
-    FUNCTION_TEST_RETURN_P(VOID, result == NULL ? itemDefault : result);
+    FUNCTION_TEST_RETURN_CONST_P(VOID, result == NULL ? itemDefault : result);
 }
 
 /**********************************************************************************************************************************/
@@ -249,9 +268,9 @@ lstIdx(const List *const this, const void *const item)
     ASSERT(item != NULL);
 
     // Item pointers should always be aligned with the beginning of an item in the list
-    ASSERT((size_t)((unsigned char *const)item - this->list) % this->itemSize == 0);
+    ASSERT((size_t)((const unsigned char *const)item - this->pub.list) % this->pub.itemSize == 0);
 
-    const size_t result = (size_t)((unsigned char *const)item - this->list) / this->itemSize;
+    const size_t result = (size_t)((const unsigned char *const)item - this->pub.list) / this->pub.itemSize;
 
     // Item pointers should always be in range
     ASSERT(result < lstSize(this));
@@ -281,38 +300,38 @@ lstInsert(List *const this, const unsigned int listIdx, const void *const item)
             if (this->listSizeMax == 0)
             {
                 this->listSizeMax = LIST_INITIAL_SIZE;
-                this->list = memNew(this->listSizeMax * this->itemSize);
+                this->pub.list = memNew(this->listSizeMax * this->pub.itemSize);
             }
             // Else the list needs to be extended
             else
             {
                 this->listSizeMax *= 2;
-                this->list = memResize(this->list, this->listSizeMax * this->itemSize);
+                this->pub.list = memResize(this->pub.list, this->listSizeMax * this->pub.itemSize);
             }
 
-            this->listAlloc = this->list;
+            this->listAlloc = this->pub.list;
         }
         MEM_CONTEXT_END();
     }
     // Else if there is space before the beginning of the list then move the list down
     else if (
-        (this->list != this->listAlloc) &&
-        (lstSize(this) + ((uintptr_t)(this->list - this->listAlloc) / this->itemSize) == this->listSizeMax))
+        (this->pub.list != this->listAlloc) &&
+        (lstSize(this) + ((uintptr_t)(this->pub.list - this->listAlloc) / this->pub.itemSize) == this->listSizeMax))
     {
-        memmove(this->listAlloc, this->list, lstSize(this) * this->itemSize);
-        this->list = this->listAlloc;
+        memmove(this->listAlloc, this->pub.list, lstSize(this) * this->pub.itemSize);
+        this->pub.list = this->listAlloc;
     }
 
     // Calculate the position where this item will be copied
-    void *const itemPtr = this->list + (listIdx * this->itemSize);
+    void *const itemPtr = this->pub.list + (listIdx * this->pub.itemSize);
 
     // If not inserting at the end then move items down to make space
     if (listIdx != lstSize(this))
-        memmove(this->list + ((listIdx + 1) * this->itemSize), itemPtr, (lstSize(this) - listIdx) * this->itemSize);
+        memmove(this->pub.list + ((listIdx + 1) * this->pub.itemSize), itemPtr, (lstSize(this) - listIdx) * this->pub.itemSize);
 
     // Copy item into the list
     this->sortOrder = sortOrderNone;
-    memcpy(itemPtr, item, this->itemSize);
+    memcpy(itemPtr, item, this->pub.itemSize);
     this->pub.listSize++;
 
     FUNCTION_TEST_RETURN_P(VOID, itemPtr);
@@ -336,14 +355,14 @@ lstRemoveIdx(List *const this, const unsigned int listIdx)
     // If this is the first item then move the list pointer up to avoid moving all the items
     if (listIdx == 0)
     {
-        this->list += this->itemSize;
+        this->pub.list += this->pub.itemSize;
     }
     // Else remove the item by moving the items after it down
     else
     {
         memmove(
-            this->list + (listIdx * this->itemSize), this->list + ((listIdx + 1) * this->itemSize),
-            (lstSize(this) - listIdx) * this->itemSize);
+            this->pub.list + (listIdx * this->pub.itemSize), this->pub.list + ((listIdx + 1) * this->pub.itemSize),
+            (lstSize(this) - listIdx) * this->pub.itemSize);
     }
 
     FUNCTION_TEST_RETURN(LIST, this);
@@ -398,12 +417,12 @@ lstSort(List *const this, const SortOrder sortOrder)
     ASSERT(this != NULL);
     ASSERT(this->comparator != NULL);
 
-    if (this->list != NULL)
+    if (this->pub.list != NULL)
     {
         switch (sortOrder)
         {
             case sortOrderAsc:
-                qsort(this->list, lstSize(this), this->itemSize, this->comparator);
+                qsort(this->pub.list, lstSize(this), this->pub.itemSize, this->comparator);
                 break;
 
             case sortOrderDesc:
@@ -411,7 +430,7 @@ lstSort(List *const this, const SortOrder sortOrder)
                 // Assign the list that will be sorted for the comparator function to use
                 comparatorDescList = this;
 
-                qsort(this->list, lstSize(this), this->itemSize, lstComparatorDesc);
+                qsort(this->pub.list, lstSize(this), this->pub.itemSize, lstComparatorDesc);
                 break;
             }
 
