@@ -168,7 +168,7 @@ strNewDbl(const double value)
         FUNCTION_TEST_PARAM(DOUBLE, value);
     FUNCTION_TEST_END();
 
-    char working[CVT_BASE10_BUFFER_SIZE];
+    char working[CVT_DOUBLE_BUFFER_SIZE];
 
     cvtDoubleToZ(value, working, sizeof(working));
 
@@ -478,7 +478,7 @@ strCatBuf(String *const this, const Buffer *const buffer)
     ASSERT(this != NULL);
     ASSERT(buffer != NULL);
 
-    FUNCTION_TEST_RETURN(STRING, strCatZN(this, (char *)bufPtrConst(buffer), bufUsed(buffer)));
+    FUNCTION_TEST_RETURN(STRING, strCatZN(this, (const char *)bufPtrConst(buffer), bufUsed(buffer)));
 }
 
 /**********************************************************************************************************************************/
