@@ -439,6 +439,12 @@ cfgLoadUpdateOption(void)
         }
     }
 
+    // A repo must be specified when targeting time. Not all repo types support versioning so rather than try to skip repos in that
+    // case it seems to be easier to just target a specific repo. Also, depending on the type of corruption, different repos might
+    // require different target times.
+    if (cfgOptionTest(cfgOptRepoTargetTime) && cfgOptionSource(cfgOptRepo) == cfgSourceDefault)
+        THROW_FMT(OptionInvalidError, "option '" CFGOPT_REPO_TARGET_TIME "' not valid without option '" CFGOPT_REPO "'");
+
     FUNCTION_LOG_RETURN_VOID();
 }
 
@@ -525,57 +531,53 @@ cfgLoad(const unsigned int argListSize, const char *argList[])
         if (cfgOptionValid(cfgOptNeutralUmask) && cfgOptionBool(cfgOptNeutralUmask))
             umask(0000);
 
-        // If a command is set
-        if (cfgCommand() != cfgCmdNone)
+        // Initialize TCP settings
+        if (cfgOptionValid(cfgOptSckKeepAlive))
         {
-            // Initialize TCP settings
-            if (cfgOptionValid(cfgOptSckKeepAlive))
-            {
-                sckInit(
-                    cfgOptionBool(cfgOptSckBlock),
-                    cfgOptionBool(cfgOptSckKeepAlive),
-                    cfgOptionTest(cfgOptTcpKeepAliveCount) ? cfgOptionInt(cfgOptTcpKeepAliveCount) : 0,
-                    cfgOptionTest(cfgOptTcpKeepAliveIdle) ? cfgOptionInt(cfgOptTcpKeepAliveIdle) : 0,
-                    cfgOptionTest(cfgOptTcpKeepAliveInterval) ? cfgOptionInt(cfgOptTcpKeepAliveInterval) : 0);
-            }
-
-            // Set IO buffer size
-            if (cfgOptionValid(cfgOptBufferSize))
-                ioBufferSizeSet(cfgOptionUInt(cfgOptBufferSize));
-
-            // Set IO timeout
-            if (cfgOptionValid(cfgOptIoTimeout))
-                ioTimeoutMsSet(cfgOptionUInt64(cfgOptIoTimeout));
-
-            // Open the log file if this command logs to a file
-            cfgLoadLogFile();
-
-            // Create the exec-id used to identify all locals and remotes spawned by this process. This allows lock contention to be
-            // easily resolved and makes it easier to associate processes from various logs.
-            if (cfgOptionValid(cfgOptExecId) && !cfgOptionTest(cfgOptExecId))
-            {
-                // Generate some random bytes
-                uint32_t execRandom;
-                cryptoRandomBytes((unsigned char *)&execRandom, sizeof(execRandom));
-
-                // Format a string with the pid and the random bytes to serve as the exec id
-                cfgOptionSet(cfgOptExecId, cfgSourceParam, VARSTR(strNewFmt("%d-%08x", getpid(), execRandom)));
-            }
-
-            // Begin the command
-            cmdBegin();
-
-            // Initialize the lock module
-            if (cfgOptionTest(cfgOptLockPath))
-                lockInit(cfgOptionStr(cfgOptLockPath), cfgOptionStr(cfgOptExecId));
-
-            // Acquire a lock if this command requires a lock
-            if (cfgLockType() != lockTypeNone && !cfgCommandHelp() && cfgLockRequired())
-                cmdLockAcquireP();
-
-            // Update options that have complex rules
-            cfgLoadUpdateOption();
+            sckInit(
+                cfgOptionBool(cfgOptSckBlock),
+                cfgOptionBool(cfgOptSckKeepAlive),
+                cfgOptionTest(cfgOptTcpKeepAliveCount) ? cfgOptionInt(cfgOptTcpKeepAliveCount) : 0,
+                cfgOptionTest(cfgOptTcpKeepAliveIdle) ? cfgOptionInt(cfgOptTcpKeepAliveIdle) : 0,
+                cfgOptionTest(cfgOptTcpKeepAliveInterval) ? cfgOptionInt(cfgOptTcpKeepAliveInterval) : 0);
         }
+
+        // Set IO buffer size (use the default for help to lower memory usage)
+        if (cfgOptionValid(cfgOptBufferSize) && !cfgCommandHelp())
+            ioBufferSizeSet(cfgOptionUInt(cfgOptBufferSize));
+
+        // Set IO timeout
+        if (cfgOptionValid(cfgOptIoTimeout))
+            ioTimeoutMsSet(cfgOptionUInt64(cfgOptIoTimeout));
+
+        // Open the log file if this command logs to a file
+        cfgLoadLogFile();
+
+        // Create the exec-id used to identify all locals and remotes spawned by this process. This allows lock contention to be
+        // easily resolved and makes it easier to associate processes from various logs.
+        if (cfgOptionValid(cfgOptExecId) && !cfgOptionTest(cfgOptExecId))
+        {
+            // Generate some random bytes
+            uint32_t execRandom;
+            cryptoRandomBytes((unsigned char *)&execRandom, sizeof(execRandom));
+
+            // Format a string with the pid and the random bytes to serve as the exec id
+            cfgOptionSet(cfgOptExecId, cfgSourceParam, VARSTR(strNewFmt("%d-%08x", getpid(), execRandom)));
+        }
+
+        // Begin the command
+        cmdBegin();
+
+        // Initialize the lock module
+        if (cfgOptionTest(cfgOptLockPath))
+            lockInit(cfgOptionStr(cfgOptLockPath), cfgOptionStr(cfgOptExecId));
+
+        // Acquire a lock if this command requires a lock
+        if (cfgLockType() != lockTypeNone && !cfgCommandHelp() && cfgLockRequired())
+            cmdLockAcquireP();
+
+        // Update options that have complex rules
+        cfgLoadUpdateOption();
     }
     MEM_CONTEXT_TEMP_END();
 
