@@ -19,6 +19,11 @@ Prefix for environment variables
 #define PGBACKREST_ENV                                              "PGBACKREST_"
 #define PGBACKREST_ENV_SIZE                                         (sizeof(PGBACKREST_ENV) - 1)
 
+/***********************************************************************************************************************************
+In some environments this will not be extern'd
+***********************************************************************************************************************************/
+extern char **environ;
+
 /***********************************************************************************************************************************
 Option type enum
 ***********************************************************************************************************************************/
