@@ -84,6 +84,7 @@ sub containerWrite
     my $oStorageDocker = shift;
     my $strTempPath = shift;
     my $strOS = shift;
+    my $strArch = shift;
     my $strTitle = shift;
     my $strImageParent = shift;
     my $strImage = shift;
@@ -104,14 +105,16 @@ sub containerWrite
     my $strScriptSha1;
     my $bCached = false;
 
-    if ($strImage =~ /\-base$/)
+    if ($strImage =~ /\-base\-/)
     {
         $strScriptSha1 = sha1_hex($strScript);
 
         foreach my $strBuild (reverse(keys(%{$hContainerCache})))
         {
-            if (defined($hContainerCache->{$strBuild}{hostArch()}{$strOS}) &&
-                $hContainerCache->{$strBuild}{hostArch()}{$strOS} eq $strScriptSha1)
+            my $strArchLookup = defined($strArch) ? $strArch : hostArch();
+
+            if (defined($hContainerCache->{$strBuild}{$strArchLookup}{$strOS}) &&
+                $hContainerCache->{$strBuild}{$strArchLookup}{$strOS} eq $strScriptSha1)
             {
                 &log(INFO, "Using cached ${strTag}-${strBuild} image (${strScriptSha1}) ...");
 
@@ -132,7 +135,8 @@ sub containerWrite
     # Write the image
     $oStorageDocker->put("${strTempPath}/${strImage}", trim($strScript) . "\n");
     executeTest(
-        'docker build' . (defined($bForce) && $bForce ? ' --no-cache' : '') . " -f ${strTempPath}/${strImage} -t ${strTag} " .
+        'docker build' . (defined($strArch) ? " --platform linux/${strArch}" : '') .
+        (defined($bForce) && $bForce ? ' --no-cache' : '') . " -f ${strTempPath}/${strImage} -t ${strTag} " .
             $oStorageDocker->pathGet('test'),
         {bSuppressStdErr => true, bShowOutputAsync => (logLevel())[1] eq DETAIL});
 }
@@ -338,6 +342,7 @@ sub containerBuild
 {
     my $oStorageDocker = shift;
     my $strVm = shift;
+    my $strArch = shift;
     my $bVmForce = shift;
 
     # Create temp path
@@ -378,8 +383,10 @@ sub containerBuild
 
         # Base image
         ###########################################################################################################################
-        my $strImageParent = "$$oVm{$strOS}{&VM_IMAGE}";
-        my $strImage = "${strOS}-base";
+        my $strImageParent =
+            (defined($strArch) ? "${strArch}/" : (vmArch($strOS) eq VM_ARCH_AMD64 ? '' : vmArch($strOS) . '/')) .
+            "$$oVm{$strOS}{&VM_IMAGE}";
+        my $strImage = "${strOS}-base" . (defined($strArch) ? "-${strArch}" : '-' . hostArch());
         my $strCopy = undef;
 
         #---------------------------------------------------------------------------------------------------------------------------
@@ -490,13 +497,17 @@ sub containerBuild
                     $strScript .=
                         "    echo \"deb http://apt.postgresql.org/pub/repos/apt/ \$(lsb_release -s -c)-pgdg main" .
                             "\" >> /etc/apt/sources.list.d/pgdg.list && \\\n" .
+                        ($strOS eq VM_U22 ?
+                            "    echo \"deb http://apt.postgresql.org/pub/repos/apt/ \$(lsb_release -s -c)-pgdg-snapshot main" .
+                            " 18\" >> /etc/apt/sources.list.d/pgdg.list && \\\n" : '') .
                         "    wget --quiet -O - https://www.postgresql.org/media/keys/ACCC4CF8.asc | apt-key add - && \\\n" .
                         "    apt-get update && \\\n";
                 }
 
                 $strScript .=
-                    "    apt-get install -y --no-install-recommends postgresql-common libpq-dev && \\\n" .
-                    "    sed -i 's/^\\#create\\_main\\_cluster.*\$/create\\_main\\_cluster \\= false/' " .
+                    "    apt-get install -y --no-install-recommends" .
+                    ($strOS eq VM_U22 ? " -t \$(lsb_release -s -c)-pgdg-snapshot" : '') . " postgresql-common libpq-dev && \\\n" .
+                     "    sed -i 's/^\\#create\\_main\\_cluster.*\$/create\\_main\\_cluster \\= false/' " .
                         "/etc/postgresql-common/createcluster.conf";
             }
 
@@ -511,8 +522,10 @@ sub containerBuild
                 }
                 else
                 {
-                    $strScript .= "    apt-get install -y --no-install-recommends";
-                 }
+                    $strScript .=
+                       "    apt-get install -y --no-install-recommends" .
+                        ($strOS eq VM_U22 ? " -t \$(lsb_release -s -c)-pgdg-snapshot" : '');
+                  }
 
                 # Construct list of databases to install
                 foreach my $strDbVersion (@{$oOS->{&VM_DB}})
@@ -538,7 +551,7 @@ sub containerBuild
             }
         }
 
-        # Add path to lastest version of postgres
+        # Add path to latest version of postgres
         if ($$oVm{$strOS}{&VM_OS_BASE} eq VM_OS_BASE_RHEL)
         {
             $strScript .=
@@ -559,14 +572,14 @@ sub containerBuild
         }
 
         containerWrite(
-            $oStorageDocker, $strTempPath, $strOS, 'Base', $strImageParent, $strImage, $strCopy, $strScript, $bVmForce);
+            $oStorageDocker, $strTempPath, $strOS, $strArch, 'Base', $strImageParent, $strImage, $strCopy, $strScript, $bVmForce);
 
         # Test image
         ########################################################################################################################
         if (!$bDeprecated)
         {
-            $strImageParent = containerRepo() . ":${strOS}-base";
-            $strImage = "${strOS}-test";
+            $strImageParent = containerRepo() . ":${strImage}";
+            $strImage = "${strOS}-test" . (defined($strArch) ? "-${strArch}" : '-' . hostArch());
 
             $strCopy = undef;
             $strScript = '';
@@ -641,7 +654,8 @@ sub containerBuild
             $strScript .= entryPointSetup($strOS);
 
             containerWrite(
-                $oStorageDocker, $strTempPath, $strOS, 'Test', $strImageParent, $strImage, $strCopy, $strScript, $bVmForce);
+                $oStorageDocker, $strTempPath, $strOS, $strArch, 'Test', $strImageParent, $strImage, $strCopy, $strScript,
+                $bVmForce);
         }
     }
 
