@@ -203,7 +203,6 @@ my $oyVm =
 
         &VM_DB =>
         [
-            PG_VERSION_94,
             PG_VERSION_95,
             PG_VERSION_96,
             PG_VERSION_10,
@@ -218,7 +217,6 @@ my $oyVm =
 
         &VM_DB_TEST =>
         [
-            PG_VERSION_94,
             PG_VERSION_95,
             PG_VERSION_96,
         ],
@@ -237,7 +235,6 @@ my $oyVm =
 
         &VM_DB =>
         [
-            PG_VERSION_94,
             PG_VERSION_95,
             PG_VERSION_96,
             PG_VERSION_10,
@@ -248,6 +245,7 @@ my $oyVm =
             PG_VERSION_15,
             PG_VERSION_16,
             PG_VERSION_17,
+            PG_VERSION_18,
         ],
 
         &VM_DB_TEST =>
@@ -256,6 +254,7 @@ my $oyVm =
             PG_VERSION_11,
             PG_VERSION_12,
             PG_VERSION_17,
+            PG_VERSION_18,
         ],
     },
 };
@@ -382,6 +381,18 @@ sub vmCoverageC
 
 push @EXPORT, qw(vmCoverageC);
 
+####################################################################################################################################
+# Get vm architecture
+####################################################################################################################################
+sub vmArch
+{
+    my $strVm = shift;
+
+    return $oyVm->{$strVm}{&VM_ARCH};
+}
+
+push @EXPORT, qw(vmArch);
+
 ####################################################################################################################################
 # Get vm architecture bits
 ####################################################################################################################################
@@ -389,7 +400,7 @@ sub vmArchBits
 {
     my $strVm = shift;
 
-    return ($oyVm->{$strVm}{&VM_ARCH} eq VM_ARCH_I386 ? 32 : 64);
+    return (vmArch($strVm) eq VM_ARCH_I386 ? 32 : 64);
 }
 
 push @EXPORT, qw(vmArchBits);
