@@ -1,6 +1,8 @@
 /***********************************************************************************************************************************
 Harness for Stack Trace Testing
 ***********************************************************************************************************************************/
+#ifndef TEST_COMMON_HARNESS_STACKTRACE_H
+#define TEST_COMMON_HARNESS_STACKTRACE_H
 
 /***********************************************************************************************************************************
 Functions
@@ -10,3 +12,5 @@ Functions
 void hrnStackTraceBackShimInstall(void);
 void hrnStackTraceBackShimUninstall(void);
 #endif
+
+#endif
