@@ -37,6 +37,7 @@ static bool testContainerData = false;
 static bool testLogExpectData = false;
 static unsigned int testIdxData = 0;
 static bool testTiming = true;
+static const char *testArchitectureData = NULL;
 static const char *testPathData = NULL;
 static const char *testUserData = NULL;
 static const char *testVmData = NULL;
@@ -58,22 +59,15 @@ static struct HarnessTestLocal
     } result;
 } harnessTestLocal;
 
-/***********************************************************************************************************************************
-Extern functions
-***********************************************************************************************************************************/
-#ifdef HRN_FEATURE_LOG
-void harnessLogInit(void);
-void harnessLogFinal(void);
-#endif
-
 /***********************************************************************************************************************************
 Initialize harness
 ***********************************************************************************************************************************/
 void
 hrnInit(
     const char *const testExe, const char *const testProjectExe, const bool testContainer, const bool testLogExpect,
-    const unsigned int testIdx, const bool timing, const char *const testPath, const char *const testUser, const char *const testVm,
-    const char *const testPgVersion,const char *const testDataPath, const char *const testRepoPath)
+    const unsigned int testIdx, const bool timing, const char *const architecture, const char *const testPath,
+    const char *const testUser, const char *const testVm, const char *const testPgVersion,const char *const testDataPath,
+    const char *const testRepoPath)
 {
     FUNCTION_HARNESS_VOID();
 
@@ -85,6 +79,7 @@ hrnInit(
     (void)testLogExpectData;
     testIdxData = testIdx;
     testTiming = timing;
+    testArchitectureData = architecture;
     testPathData = testPath;
     testUserData = testUser;
     testVmData = testVm;
@@ -283,7 +278,7 @@ hrnFileWrite(const char *fileName, const unsigned char *buffer, size_t bufferSiz
 }
 
 /**********************************************************************************************************************************/
-char harnessDiffBuffer[256 * 1024];
+static char harnessDiffBuffer[256 * 1024];
 
 const char *
 hrnDiff(const char *expected, const char *actual)
@@ -298,12 +293,12 @@ hrnDiff(const char *expected, const char *actual)
     // Write expected file
     char expectedFile[1024];
     snprintf(expectedFile, sizeof(expectedFile), "%s/diff.expected", hrnPath());
-    hrnFileWrite(expectedFile, (unsigned char *)expected, strlen(expected));
+    hrnFileWrite(expectedFile, (const unsigned char *)expected, strlen(expected));
 
     // Write actual file
     char actualFile[1024];
     snprintf(actualFile, sizeof(actualFile), "%s/diff.actual", hrnPath());
-    hrnFileWrite(actualFile, (unsigned char *)actual, strlen(actual));
+    hrnFileWrite(actualFile, (const unsigned char *)actual, strlen(actual));
 
     // Perform diff
     char command[2560];
@@ -531,8 +526,8 @@ hrnTestResultDouble(double actual, double expected)
 
     if (actual != expected)
     {
-        char actualZ[256];
-        char expectedZ[256];
+        char actualZ[318];
+        char expectedZ[318];
 
         snprintf(actualZ, sizeof(actualZ), "%f", actual);
         snprintf(expectedZ, sizeof(expectedZ), "%f", expected);
@@ -691,7 +686,7 @@ hrnTestResultZ(const char *actual, const char *expected, HarnessTestResultOperat
         case harnessTestResultOperationNe:
             result =
                 (actual == NULL && expected != NULL) || (actual != NULL && expected == NULL) ||
-                (actual != NULL && expected != NULL && strcmp(actual, expected) == 0);
+                (actual != NULL && expected != NULL && strcmp(actual, expected) != 0);
             break;
     }
 
@@ -759,6 +754,14 @@ testUser(void)
     FUNCTION_HARNESS_RETURN(STRINGZ, testUserData);
 }
 
+/**********************************************************************************************************************************/
+const char *
+testArchitecture(void)
+{
+    FUNCTION_HARNESS_VOID();
+    FUNCTION_HARNESS_RETURN(STRINGZ, testArchitectureData);
+}
+
 /**********************************************************************************************************************************/
 const char *
 testVm(void)
