@@ -30,17 +30,19 @@ testRun(void)
         TEST_RESULT_Z(destinationEncode, "c3Ry", "3 character encode");
         TEST_RESULT_UINT(encodeToStrSize(encodingBase64, 3), strlen(destinationEncode), "check size");
 
-        encodeToStr(encodingBase64, encode, strlen((char *)encode) - 2, destinationEncode);
+        encodeToStr(encodingBase64, encode, strlen((const char *)encode) - 2, destinationEncode);
         TEST_RESULT_Z(destinationEncode, "c3RyaW5nX3RvX2VuY29kZQ==", "encode full string");
-        TEST_RESULT_UINT(encodeToStrSize(encodingBase64, strlen((char *)encode) - 2), strlen(destinationEncode), "check size");
+        TEST_RESULT_UINT(
+            encodeToStrSize(encodingBase64, strlen((const char *)encode) - 2), strlen(destinationEncode), "check size");
 
-        encodeToStr(encodingBase64, encode, strlen((char *)encode), destinationEncode);
+        encodeToStr(encodingBase64, encode, strlen((const char *)encode), destinationEncode);
         TEST_RESULT_Z(destinationEncode, "c3RyaW5nX3RvX2VuY29kZQ0K", "encode full string with \\r\\n");
-        TEST_RESULT_UINT(encodeToStrSize(encodingBase64, strlen((char *)encode)), strlen(destinationEncode), "check size");
+        TEST_RESULT_UINT(encodeToStrSize(encodingBase64, strlen((const char *)encode)), strlen(destinationEncode), "check size");
 
-        encodeToStr(encodingBase64, encode, strlen((char *)encode) + 1, destinationEncode);
+        encodeToStr(encodingBase64, encode, strlen((const char *)encode) + 1, destinationEncode);
         TEST_RESULT_Z(destinationEncode, "c3RyaW5nX3RvX2VuY29kZQ0KAA==", "encode full string with \\r\\n and null");
-        TEST_RESULT_UINT(encodeToStrSize(encodingBase64, strlen((char *)encode) + 1), strlen(destinationEncode), "check size");
+        TEST_RESULT_UINT(
+            encodeToStrSize(encodingBase64, strlen((const char *)encode) + 1), strlen(destinationEncode), "check size");
 
         // -------------------------------------------------------------------------------------------------------------------------
         unsigned char destinationDecode[256];
@@ -48,23 +50,23 @@ testRun(void)
         memset(destinationDecode, 0xFF, sizeof(destinationDecode));
         const char *decode = "c3RyaW5nX3RvX2VuY29kZQ0KAA==";
         decodeToBin(encodingBase64, decode, destinationDecode);
-        TEST_RESULT_Z((char *)destinationDecode, (char *)encode, "full string with \\r\\n and null decode");
-        TEST_RESULT_INT(destinationDecode[strlen((char *)encode) + 1], 0xFF, "check for overrun");
-        TEST_RESULT_UINT(decodeToBinSize(encodingBase64, decode), strlen((char *)encode) + 1, "check size");
+        TEST_RESULT_Z((char *)destinationDecode, (const char *)encode, "full string with \\r\\n and null decode");
+        TEST_RESULT_INT(destinationDecode[strlen((const char *)encode) + 1], 0xFF, "check for overrun");
+        TEST_RESULT_UINT(decodeToBinSize(encodingBase64, decode), strlen((const char *)encode) + 1, "check size");
 
         memset(destinationDecode, 0xFF, sizeof(destinationDecode));
         decode = "c3RyaW5nX3RvX2VuY29kZQ0K";
         decodeToBin(encodingBase64, decode, destinationDecode);
-        TEST_RESULT_INT(memcmp(destinationDecode, encode, strlen((char *)encode)), 0, "full string with \\r\\n decode");
-        TEST_RESULT_INT(destinationDecode[strlen((char *)encode)], 0xFF, "check for overrun");
-        TEST_RESULT_UINT(decodeToBinSize(encodingBase64, decode), strlen((char *)encode), "check size");
+        TEST_RESULT_INT(memcmp(destinationDecode, encode, strlen((const char *)encode)), 0, "full string with \\r\\n decode");
+        TEST_RESULT_INT(destinationDecode[strlen((const char *)encode)], 0xFF, "check for overrun");
+        TEST_RESULT_UINT(decodeToBinSize(encodingBase64, decode), strlen((const char *)encode), "check size");
 
         memset(destinationDecode, 0xFF, sizeof(destinationDecode));
         decode = "c3RyaW5nX3RvX2VuY29kZQ==";
         decodeToBin(encodingBase64, decode, destinationDecode);
-        TEST_RESULT_INT(memcmp(destinationDecode, encode, strlen((char *)encode) - 2), 0, "full string decode");
-        TEST_RESULT_INT(destinationDecode[strlen((char *)encode) - 2], 0xFF, "check for overrun");
-        TEST_RESULT_UINT(decodeToBinSize(encodingBase64, decode), strlen((char *)encode) - 2, "check size");
+        TEST_RESULT_INT(memcmp(destinationDecode, encode, strlen((const char *)encode) - 2), 0, "full string decode");
+        TEST_RESULT_INT(destinationDecode[strlen((const char *)encode) - 2], 0xFF, "check for overrun");
+        TEST_RESULT_UINT(decodeToBinSize(encodingBase64, decode), strlen((const char *)encode) - 2, "check size");
 
         memset(destinationDecode, 0xFF, sizeof(destinationDecode));
         decode = "c3Ry";
@@ -122,17 +124,19 @@ testRun(void)
         TEST_RESULT_Z(destinationEncode, "c3Ry", "3 character encode");
         TEST_RESULT_UINT(encodeToStrSize(encodingBase64Url, 3), strlen(destinationEncode), "check size");
 
-        encodeToStr(encodingBase64Url, encode, strlen((char *)encode) - 2, destinationEncode);
+        encodeToStr(encodingBase64Url, encode, strlen((const char *)encode) - 2, destinationEncode);
         TEST_RESULT_Z(destinationEncode, "c3RyaW5nX3RvX2VuY29kZQ", "encode full string");
-        TEST_RESULT_UINT(encodeToStrSize(encodingBase64Url, strlen((char *)encode) - 2), strlen(destinationEncode), "check size");
+        TEST_RESULT_UINT(
+            encodeToStrSize(encodingBase64Url, strlen((const char *)encode) - 2), strlen(destinationEncode), "check size");
 
-        encodeToStr(encodingBase64Url, encode, strlen((char *)encode), destinationEncode);
+        encodeToStr(encodingBase64Url, encode, strlen((const char *)encode), destinationEncode);
         TEST_RESULT_Z(destinationEncode, "c3RyaW5nX3RvX2VuY29kZQ0K", "encode full string with \\r\\n");
-        TEST_RESULT_UINT(encodeToStrSize(encodingBase64Url, strlen((char *)encode)), strlen(destinationEncode), "check size");
+        TEST_RESULT_UINT(encodeToStrSize(encodingBase64Url, strlen((const char *)encode)), strlen(destinationEncode), "check size");
 
-        encodeToStr(encodingBase64Url, encode, strlen((char *)encode) + 1, destinationEncode);
+        encodeToStr(encodingBase64Url, encode, strlen((const char *)encode) + 1, destinationEncode);
         TEST_RESULT_Z(destinationEncode, "c3RyaW5nX3RvX2VuY29kZQ0KAA", "encode full string with \\r\\n and null");
-        TEST_RESULT_UINT(encodeToStrSize(encodingBase64Url, strlen((char *)encode) + 1), strlen(destinationEncode), "check size");
+        TEST_RESULT_UINT(
+            encodeToStrSize(encodingBase64Url, strlen((const char *)encode) + 1), strlen(destinationEncode), "check size");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("decode unsupported");
@@ -149,19 +153,19 @@ testRun(void)
         TEST_TITLE("encode");
 
         const unsigned char *encode = (const unsigned char *)"string_to_encode\r\n";
-        char destinationEncode[256];
+        char destinationEncode[513];
 
         encodeToStr(encodingHex, encode, 1, destinationEncode);
         TEST_RESULT_Z(destinationEncode, "73", "1 character encode");
         TEST_RESULT_UINT(encodeToStrSize(encodingHex, 1), strlen(destinationEncode), "check size");
 
-        encodeToStr(encodingHex, encode, strlen((char *)encode), destinationEncode);
+        encodeToStr(encodingHex, encode, strlen((const char *)encode), destinationEncode);
         TEST_RESULT_Z(destinationEncode, "737472696e675f746f5f656e636f64650d0a", "encode full string with \\r\\n");
-        TEST_RESULT_UINT(encodeToStrSize(encodingHex, strlen((char *)encode)), strlen(destinationEncode), "check size");
+        TEST_RESULT_UINT(encodeToStrSize(encodingHex, strlen((const char *)encode)), strlen(destinationEncode), "check size");
 
-        encodeToStr(encodingHex, encode, strlen((char *)encode) + 1, destinationEncode);
+        encodeToStr(encodingHex, encode, strlen((const char *)encode) + 1, destinationEncode);
         TEST_RESULT_Z(destinationEncode, "737472696e675f746f5f656e636f64650d0a00", "encode full string with \\r\\n and null");
-        TEST_RESULT_UINT(encodeToStrSize(encodingHex, strlen((char *)encode) + 1), strlen(destinationEncode), "check size");
+        TEST_RESULT_UINT(encodeToStrSize(encodingHex, strlen((const char *)encode) + 1), strlen(destinationEncode), "check size");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("decode");
@@ -171,9 +175,9 @@ testRun(void)
         memset(destinationDecode, 0xFF, sizeof(destinationDecode));
         const char *decode = "737472696e675f746f5f656e636f64650d0a00";
         decodeToBin(encodingHex, decode, destinationDecode);
-        TEST_RESULT_Z((char *)destinationDecode, (char *)encode, "full string with \\r\\n and null decode");
-        TEST_RESULT_INT(destinationDecode[strlen((char *)encode) + 1], 0xFF, "check for overrun");
-        TEST_RESULT_UINT(decodeToBinSize(encodingHex, decode), strlen((char *)encode) + 1, "check size");
+        TEST_RESULT_Z((char *)destinationDecode, (const char *)encode, "full string with \\r\\n and null decode");
+        TEST_RESULT_INT(destinationDecode[strlen((const char *)encode) + 1], 0xFF, "check for overrun");
+        TEST_RESULT_UINT(decodeToBinSize(encodingHex, decode), strlen((const char *)encode) + 1, "check size");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("decode/encode with mixed case");
@@ -185,6 +189,20 @@ testRun(void)
             encodeToStr(encodingHex, destinationDecode, decodeToBinSize(encodingHex, decodeMixed), destinationEncode), "encode");
         TEST_RESULT_Z(destinationEncode, "0123456789aabbccddeeff", "check encoded hex");
 
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("decode/encode all values");
+
+        unsigned char decodedAll[256];
+
+        for (unsigned int decodeIdx = 0; decodeIdx < sizeof(decodedAll); decodeIdx++)
+            decodedAll[decodeIdx] = (unsigned char)decodeIdx;
+
+        encodeToStr(encodingHex, decodedAll, sizeof(decodedAll), destinationEncode);
+        TEST_RESULT_UINT(strlen(destinationEncode), 512, "all values encoded size");
+        TEST_RESULT_INT(memcmp(destinationEncode, encodeHexLookup, 512), 0, "all values encoded");
+        decodeToBin(encodingHex, destinationEncode, destinationDecode);
+        TEST_RESULT_INT(memcmp(decodedAll, destinationDecode, sizeof(decodedAll)), 0, "all values decoded");
+
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("decode errors");
 
