@@ -491,6 +491,24 @@ testRun(void)
         hrnCfgEnvKeyRemoveRaw(cfgOptRepoS3Key, 1);
         hrnCfgEnvKeyRemoveRaw(cfgOptRepoS3KeySecret, 1);
 
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("repo is set when repo-target-time is set");
+
+        argList = strLstNew();
+        hrnCfgArgRawZ(argList, cfgOptStanza, "db");
+        hrnCfgArgRawZ(argList, cfgOptRepoPath, "/repo");
+        hrnCfgArgRawZ(argList, cfgOptRepoTargetTime, "2024-08-08 12:12:12+00");
+        TEST_ERROR(
+            hrnCfgLoadP(cfgCmdInfo, argList), OptionInvalidError, "option 'repo-target-time' not valid without option 'repo'");
+
+        hrnCfgArgRawZ(argList, cfgOptPgPath, "/path/to/pg");
+        TEST_ERROR(
+            hrnCfgLoadP(cfgCmdArchiveGet, argList), OptionInvalidError,
+            "option 'repo-target-time' not valid without option 'repo'");
+
+        hrnCfgArgRawZ(argList, cfgOptRepo, "1");
+        HRN_CFG_LOAD(cfgCmdArchiveGet, argList);
+
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("compress-type=none when compress=n");
 
@@ -862,8 +880,10 @@ testRun(void)
         hrnCfgArgRawZ(argList, cfgOptLogLevelFile, "off");
         hrnCfgArgRawZ(argList, cfgOptRepoRetentionFull, "2");
 
+        ioBufferSizeSet(333);
+
         TEST_RESULT_VOID(cfgLoad(strLstSize(argList), strLstPtr(argList)), "help command for backup");
-        TEST_RESULT_UINT(ioBufferSize(), 1048576, "buffer size set to option default");
+        TEST_RESULT_UINT(ioBufferSize(), 333, "buffer size not updated by help command");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("help command for help");
@@ -873,8 +893,10 @@ testRun(void)
         strLstAddZ(argList, "help");
         strLstAddZ(argList, "help");
 
+        ioBufferSizeSet(333);
+
         TEST_RESULT_VOID(cfgLoad(strLstSize(argList), strLstPtr(argList)), "load config");
-        TEST_RESULT_UINT(ioBufferSize(), 1048576, "buffer size set to option default");
+        TEST_RESULT_UINT(ioBufferSize(), 333, "buffer size not updated by help command");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("command takes lock and opens log file and uses custom tcp settings");
