@@ -143,6 +143,32 @@ testRun(void)
         #undef TEST_PQ_ERROR
         #undef TEST_QUERY
 
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("unable to execute query that returns no results");
+
+        #define TEST_PQ_ERROR                                                                                                      \
+            "ERROR:  must be superuser or have privileges of pg_checkpoint to do CHECKPOINT"
+        #define TEST_QUERY                                          "checkpoint"
+
+#ifndef HARNESS_PQ_REAL
+        HRN_PQ_SCRIPT_SET(
+            {.function = HRN_PQ_SENDQUERY, .param = "[\"" TEST_QUERY "\"]", .resultInt = 1},
+            {.function = HRN_PQ_CONSUMEINPUT},
+            {.function = HRN_PQ_ISBUSY},
+            {.function = HRN_PQ_GETRESULT},
+            {.function = HRN_PQ_RESULTSTATUS, .resultInt = PGRES_FATAL_ERROR},
+            {.function = HRN_PQ_RESULTERRORMESSAGE, .resultZ = TEST_PQ_ERROR},
+            {.function = HRN_PQ_CLEAR},
+            {.function = HRN_PQ_GETRESULT, .resultNull = true});
+#endif
+
+        TEST_ERROR(
+            pgClientQuery(client, STRDEF(TEST_QUERY), pgClientQueryResultNone), DbQueryError,
+            "unable to execute query '" TEST_QUERY "': " TEST_PQ_ERROR);
+
+        #undef TEST_PQ_ERROR
+        #undef TEST_QUERY
+
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("query timeout");
 
