@@ -32,7 +32,7 @@ testRun(void)
         PROTOCOL_SERVER_HANDLER_STORAGE_REMOTE_LIST
     };
 
-    hrnProtocolRemoteShimInstall(testRemoteHandlerList, LENGTH_OF(testRemoteHandlerList));
+    hrnProtocolRemoteShimInstall(LSTDEF(testRemoteHandlerList));
 
     // Set filter handlers
     static const StorageRemoteFilterHandler storageRemoteFilterHandlerList[] =
@@ -43,7 +43,7 @@ testRun(void)
         {.type = SIZE_FILTER_TYPE, .handlerNoParam = ioSizeNew},
     };
 
-    storageRemoteFilterHandlerSet(storageRemoteFilterHandlerList, LENGTH_OF(storageRemoteFilterHandlerList));
+    storageRemoteFilterHandlerSet(LSTDEF(storageRemoteFilterHandlerList));
 
     // Test storage
     Storage *storageTest = storagePosixNewP(TEST_PATH_STR, .write = true);
@@ -784,7 +784,7 @@ testRun(void)
     // sure coverage data has been written by the remote. We also need to make sure that the mem context callback is cleared so that
     // protocolClientFreeResource() will not be called and send another exit. protocolFree() is still required to free the client
     // objects.
-    ProtocolClient *client = protocolRemoteGet(protocolStorageTypeRepo, 0);
+    ProtocolClient *client = protocolRemoteGet(protocolStorageTypeRepo, 0, true);
 
     memContextCallbackClear(objMemContext(client));
 
@@ -793,7 +793,7 @@ testRun(void)
 
     protocolClientRequestP(client, PROTOCOL_COMMAND_EXIT);
 
-    client = protocolRemoteGet(protocolStorageTypePg, 1);
+    client = protocolRemoteGet(protocolStorageTypePg, 1, true);
 
     for (unsigned int sessionIdx = 0; sessionIdx < lstSize(client->sessionList); sessionIdx++)
         memContextCallbackClear(objMemContext(*(ProtocolClientSession **)lstGet(client->sessionList, sessionIdx)));
