@@ -66,6 +66,37 @@ testRun(void)
         TEST_RESULT_STR_Z(cmdBldPathRelative(STRDEF("/tmp"), STRDEF("/tmp/sub")), "sub", "base is sub of compare");
     }
 
+    // *****************************************************************************************************************************
+    if (testBegin("lint*()"))
+    {
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("lintStrId()");
+
+        HRN_STORAGE_PUT_Z(
+            storageTest, "repo/test.c",
+            "#define STRID5(str, strId)\n"
+            "#define STRID6(str, strId)\n"
+            "STR" "ID5(\"abcd\", TEST_STRID)\n"
+            "STR" "ID5(\\\"abcd\\\")\n"
+            "STR" "ID5(\\\"abcd)\n"
+            "STR" "ID5(abcd)\n"
+            "STR" "ID5( \"abcd)\n"
+            "STRID5(\"abcd\")\n"
+            "STRID5(\"abcd\", 0x20c410)\n");
+
+        TEST_ERROR(
+            cmdTest(
+                STRDEF(TEST_PATH "/repo"), storagePathP(storageTest, STRDEF("test")), STRDEF("none"), 3, STRDEF("invalid"),
+                STRDEF("common/stack-trace"), 0, 1, logLevelDebug, true, NULL, false, false, false, true),
+            FormatError, "4 linter error(s) in 'test.c' (see warnings above)");
+
+        TEST_RESULT_LOG(
+            "P00   WARN: 'STR" "ID5(\\\"abcd)' must have quotes around string parameter '\\\"abcd'\n"
+            "P00   WARN: 'STR" "ID5(abcd)' must have quotes around string parameter 'abcd'\n"
+            "P00   WARN: 'STR" "ID5( \"abcd)' must have quotes around string parameter '\"abcd'\n"
+            "P00   WARN: 'STRID5(\"abcd\")' should be 'STRID5(\"abcd\", 0x20c410)'");
+    }
+
     // *****************************************************************************************************************************
     if (testBegin("TestDef and TestBuild"))
     {
@@ -121,6 +152,7 @@ testRun(void)
         strReplace(testC, STRDEF("{[C_TEST_USER_ID]}"), STRDEF(TEST_USER_ID_Z));
         strReplace(testC, STRDEF("{[C_TEST_USER_ID_Z]}"), STRDEF("\"" TEST_USER_ID_Z "\""));
         strReplace(testC, STRDEF("{[C_TEST_USER_LEN]}"), strNewFmt("%zu", sizeof(TEST_USER) - 1));
+        strReplace(testC, STRDEF("{[C_TEST_ARCHITECTURE]}"), STRDEF(TEST_ARCHITECTURE));
 
         // Test definition
         // -------------------------------------------------------------------------------------------------------------------------
@@ -502,12 +534,13 @@ testRun(void)
         HRN_STORAGE_PUT_Z(storageTest, "repo/test/src/common/shim.c", strZ(shimC));
         HRN_STORAGE_PUT_Z(
             storageTest, "repo/test/src/common/shim2.c",
+            "int noShimFunc3(void);"
             "int noShimFunc3(void)\n"
             "{\n"
             "    return 888;\n"
             "}\n");
 
-        strReplace(shimC, STRDEF("int\nshimFunc(void)"), STRDEF("int\nshimFunc_SHIMMED(void)"));
+        strReplace(shimC, STRDEF("int\nshimFunc(void)"), STRDEF("int shimFunc_SHIMMED(void); int\nshimFunc_SHIMMED(void)"));
         strReplace(
             shimC, STRDEF("static int\nshimFunc2("),
             STRDEF("static int shimFunc2(int param1, int param2); static int\nshimFunc2_SHIMMED("));
