@@ -74,7 +74,6 @@ test.pl [options]
    --container-only     only run tests that must be run in a container
    --no-performance     do not run performance tests
    --gen-only           only run auto-generation
-   --min-gen            only run required code generation
    --gen-check          check that auto-generated files are correct (used in CI to detect changes)
    --code-count         generate code counts
    --no-back-trace      don't run backrace on C unit tests (may be slow with valgrind)
@@ -108,6 +107,7 @@ test.pl [options]
 
  VM Options:
    --vm                 docker container to build/test (e.g. rh8)
+   --vm-arch            docker container architecture
    --vm-build           build Docker containers
    --vm-force           force a rebuild of Docker containers
    --vm-out             Show VM output (default false)
@@ -144,6 +144,7 @@ my $bHelp = false;
 my $bQuiet = false;
 my $strPgVersion = 'minimal';
 my $strVm = VM_NONE;
+my $strVmArch;
 my $bVmBuild = false;
 my $bVmForce = false;
 my $bBuildOnly = false;
@@ -158,7 +159,6 @@ my $bContainerOnly = false;
 my $bNoPerformance = false;
 my $bGenOnly = false;
 my $bGenCheck = false;
-my $bMinGen = false;
 my $bCodeCount = false;
 my $bProfile = false;
 my $bNoBackTrace = false;
@@ -185,6 +185,7 @@ GetOptions ('q|quiet' => \$bQuiet,
             'log-level-test-file=s' => \$strLogLevelTestFile,
             'no-log-timestamp' => \$bNoLogTimestamp,
             'vm=s' => \$strVm,
+            'vm-arch=s' => \$strVmArch,
             'vm-out' => \$bVmOut,
             'vm-build' => \$bVmBuild,
             'vm-force' => \$bVmForce,
@@ -207,7 +208,6 @@ GetOptions ('q|quiet' => \$bQuiet,
             'no-performance' => \$bNoPerformance,
             'gen-only' => \$bGenOnly,
             'gen-check' => \$bGenCheck,
-            'min-gen' => \$bMinGen,
             'code-count' => \$bCodeCount,
             'code-format' => \$bCodeFormat,
             'code-format-check' => \$bCodeFormatCheck,
@@ -250,14 +250,6 @@ eval
         pod2usage();
     }
 
-    ################################################################################################################################
-    # Disable code generation on dry-run
-    ################################################################################################################################
-    if ($bDryRun)
-    {
-        $bMinGen = true;
-    }
-
     ################################################################################################################################
     # Update options for --coverage-summary
     ################################################################################################################################
@@ -375,7 +367,7 @@ eval
     ################################################################################################################################
     if ($bVmBuild)
     {
-        containerBuild($oStorageBackRest, $strVm, $bVmForce);
+        containerBuild($oStorageBackRest, $strVm, $strVmArch, $bVmForce);
         exit 0;
     }
 
@@ -429,104 +421,6 @@ eval
         }
     }
 
-    # Auto-generate configure files unless --min-gen specified
-    #-------------------------------------------------------------------------------------------------------------------------------
-    if (!$bMinGen)
-    {
-        &log(INFO, "autogenerate configure");
-
-        # Auto-generate version for configure.ac script
-        #-----------------------------------------------------------------------------------------------------------------------
-        my $strConfigureAcOld = ${$oStorageTest->get("${strBackRestBase}/src/build/configure.ac")};
-        my $strConfigureAcNew;
-
-        foreach my $strLine (split("\n", $strConfigureAcOld))
-        {
-            if ($strLine =~ /^AC_INIT\(/)
-            {
-                $strLine = 'AC_INIT([' . PROJECT_NAME . '], [' . PROJECT_VERSION . '])';
-            }
-
-            $strConfigureAcNew .= "${strLine}\n";
-        }
-
-        # Save into the src dir
-        my @stryBuilt;
-        my $strBuilt = 'src/build/configure.ac';
-
-        if (buildPutDiffers($oStorageBackRest, "${strBackRestBase}/${strBuilt}", $strConfigureAcNew))
-        {
-            push(@stryBuilt, $strBuilt);
-        }
-
-        # Error when checking that files have already been generated but they change
-        if ($bGenCheck && @stryBuilt)
-        {
-            confess &log(
-                ERROR,
-                "unexpected autogeneration of version in configure.ac script: " . join(', ', @stryBuilt) . ":\n" .
-                    trim(executeTest("git -C ${strBackRestBase} diff")));
-        }
-
-        &log(INFO,
-            "    autogenerated version in configure.ac script: " . (@stryBuilt ? join(', ', @stryBuilt) : 'no changes'));
-
-        # Auto-generate configure script
-        #-----------------------------------------------------------------------------------------------------------------------
-        # Set build file
-        @stryBuilt = ();
-        $strBuilt = 'src/configure';
-
-        # Get configure.ac and configure to see if anything has changed
-        my $strConfigureAc = ${$oStorageBackRest->get('src/build/configure.ac')};
-        my $strConfigureAcHash = sha1_hex($strConfigureAc);
-        my $rstrConfigure = $oStorageBackRest->get($oStorageBackRest->openRead($strBuilt, {bIgnoreMissing => true}));
-
-        # Check if configure needs to be regenerated
-        if (!defined($rstrConfigure) || !defined($$rstrConfigure) ||
-            $strConfigureAcHash ne substr($$rstrConfigure, length($$rstrConfigure) - 41, 40))
-        {
-            # Generate aclocal.m4
-            my $strAcLocal = executeTest("cd ${strBackRestBase}/src/build && aclocal --OUT=-");
-            $strAcLocal = trim($strAcLocal) . "\n";
-
-            buildPutDiffers($oStorageBackRest, "${strBackRestBase}/src/build/aclocal.m4", $strAcLocal);
-
-            # Generate configure
-            my $strConfigure = executeTest("cd ${strBackRestBase}/src/build && autoconf --output=-");
-            $strConfigure =
-                trim($strConfigure) . "\n\n# Generated from src/build/configure.ac sha1 ${strConfigureAcHash}\n";
-
-            # Remove cache created by autconf
-            executeTest("rm -rf ${strBackRestBase}/src/build/autom4te.cache");
-
-            # Remove unused options from help
-            my $strDirList =
-                "sbin|libexec|sysconf|sharedstate|localstate|runstate|lib|include|oldinclude|dataroot|data|info" .
-                "|locale|man|doc|html|dvi|pdf|ps";
-
-            $strConfigure =~ s/^  --(${strDirList})*dir=DIR.*\n//mg;
-
-            # Save into the src dir
-            $oStorageBackRest->put(
-                $oStorageBackRest->openWrite("${strBackRestBase}/${strBuilt}", {strMode => '0755'}), $strConfigure);
-
-            # Add to built list
-            push(@stryBuilt, $strBuilt);
-        }
-
-        # Error when checking that files have already been generated but they change
-        if ($bGenCheck && @stryBuilt)
-        {
-            confess &log(
-                ERROR,
-                "unexpected autogeneration of configure script: " . join(', ', @stryBuilt) . ":\n" .
-                    trim(executeTest("git -C ${strBackRestBase} diff")));
-        }
-
-        &log(INFO, "    autogenerated configure script: " . (@stryBuilt ? join(', ', @stryBuilt) : 'no changes'));
-    }
-
     # Auto-generate version for root meson.build script
     #-------------------------------------------------------------------------------------------------------------------------------
     my $strMesonBuildOld = ${$oStorageTest->get("${strBackRestBase}/meson.build")};
@@ -544,8 +438,35 @@ eval
 
     buildPutDiffers($oStorageBackRest, "${strBackRestBase}/meson.build", $strMesonBuildNew);
 
+    # Auto-generate version for version.h
+    #-------------------------------------------------------------------------------------------------------------------------------
+    my $strVersionCOld = ${$oStorageTest->get("${strBackRestBase}/src/version.h")};
+    my $strVersionCNew;
+
+    foreach my $strLine (split("\n", $strVersionCOld))
+    {
+        if ($strLine =~ /^#define PROJECT_VERSION /)
+        {
+            $strLine = "#define PROJECT_VERSION" . (' ' x 45) . '"' . PROJECT_VERSION . '"';
+        }
+
+        if ($strLine =~ /^#define PROJECT_VERSION_NUM /)
+        {
+            $strLine =
+                "#define PROJECT_VERSION_NUM" . (' ' x 41) .
+                sprintf('%d%03d%03d', PROJECT_VERSION_MAJOR, PROJECT_VERSION_MINOR, PROJECT_VERSION_PATCH);
+        }
+
+        $strVersionCNew .= "${strLine}\n";
+    }
+
+    buildPutDiffers($oStorageBackRest, "${strBackRestBase}/src/version.h", $strVersionCNew);
+
     # Start build container if vm is not none
     #-------------------------------------------------------------------------------------------------------------------------------
+    my $strPlatform = defined($strVmArch) ? " --platform linux/${strVmArch}" : '';
+    my $strImage = containerRepo() . ":${strVm}-test" . (defined($strVmArch) ? "-${strVmArch}" : '-' . hostArch());
+
     if ($strVm ne VM_NONE)
     {
         my $strCCachePath = "${strTestPath}/ccache-0/${strVm}";
@@ -556,9 +477,9 @@ eval
         }
 
         executeTest(
-            "docker run -itd -h test-build --name=test-build" .
+            "docker run${strPlatform} -itd -h test-build --name=test-build" .
                 " -v ${strBackRestBase}:${strBackRestBase} -v ${strTestPath}:${strTestPath}" .
-                " -v ${strCCachePath}:/home/${\TEST_USER}/.ccache" . ' ' . containerRepo() . ":${strVm}-test",
+                " -v ${strCCachePath}:/home/${\TEST_USER}/.ccache" . " ${strImage}",
             {bSuppressStdErr => true});
     }
 
@@ -569,7 +490,7 @@ eval
     # Create the repo path -- this should hopefully prevent obvious rsync errors below
     $oStorageTest->pathCreate($strRepoCachePath, {strMode => '0770', bIgnoreExists => true, bCreateParent => true});
 
-    # Auto-generate code files (if --min-gen specified then do minimum required)
+    # Auto-generate code files (if --dry-run specified then do minimum required)
     #-------------------------------------------------------------------------------------------------------------------------------
     my $strBuildPath = "${strTestPath}/build/none";
     my $strBuildNinja = "${strBuildPath}/build.ninja";
@@ -579,9 +500,9 @@ eval
     # Setup build if it does not exist
     my $strGenerateCommand =
         "ninja -C ${strBuildPath} src/build-code" .
-        ($bMinGen ? '' : " && \\\n${strBuildPath}/src/build-code config ${strBackRestBase}/src") .
-        ($bMinGen ? '' : " && \\\n${strBuildPath}/src/build-code error ${strBackRestBase}/src") .
-        ($bMinGen ? '' : " && \\\n${strBuildPath}/src/build-code postgres-version ${strBackRestBase}/src") .
+        ($bDryRun ? '' : " && \\\n${strBuildPath}/src/build-code config ${strBackRestBase}/src") .
+        ($bDryRun ? '' : " && \\\n${strBuildPath}/src/build-code error ${strBackRestBase}/src") .
+        ($bDryRun ? '' : " && \\\n${strBuildPath}/src/build-code postgres-version ${strBackRestBase}/src") .
         " && \\\n${strBuildPath}/src/build-code postgres ${strBackRestBase}/src ${strRepoCachePath}" .
         " && \\\nninja -C ${strBuildPath} test/src/test-pgbackrest";
 
@@ -651,8 +572,6 @@ eval
 
             if ($strFile eq 'doc/doc.pl' ||
                 $strFile eq 'doc/release.pl' ||
-                $strFile eq 'src/build/install-sh' ||
-                $strFile eq 'src/configure' ||
                 $strFile eq 'test/ci.pl' ||
                 $strFile eq 'test/test.pl' ||
                 $hManifest->{$strFile}{type} eq 'd')
@@ -788,8 +707,8 @@ eval
                     if ($strVm ne VM_NONE)
                     {
                         executeTest(
-                            "docker run -itd -h test-build --name=test-build" .
-                            " -v ${strBackRestBase}:${strBackRestBase} " . containerRepo() . ":${strBuildVM}-test",
+                            "docker run${strPlatform} -itd -h test-build --name=test-build" .
+                            " -v ${strBackRestBase}:${strBackRestBase} ${strImage}",
                             {bSuppressStdErr => true});
                     }
 
@@ -872,8 +791,8 @@ eval
                     if ($strVm ne VM_NONE)
                     {
                         executeTest(
-                            "docker run -itd -h test-build --name=test-build" .
-                            " -v ${strBackRestBase}:${strBackRestBase} " . containerRepo() . ":${strBuildVM}-test",
+                            "docker run${strPlatform} -itd -h test-build --name=test-build" .
+                            " -v ${strBackRestBase}:${strBackRestBase} ${strImage}",
                             {bSuppressStdErr => true});
                     }
 
@@ -1052,10 +971,10 @@ eval
             if (!defined($$oyProcess[$iVmIdx]) && $iTestIdx < @{$oyTestRun})
             {
                 my $oJob = new pgBackRestTest::Common::JobTest(
-                    $oStorageTest, $strBackRestBase, $strTestPath, $$oyTestRun[$iTestIdx], $bDryRun, $bVmOut, $iVmIdx, $iVmMax,
-                    $strMakeCmd, $iTestIdx, $iTestMax, $strLogLevel, $strLogLevelTest, $strLogLevelTestFile, !$bNoLogTimestamp,
-                    $bShowOutputAsync, $bNoCleanup, $iRetry, !$bNoBackTrace, !$bNoValgrind, !$bNoCoverage, $bCoverageSummary,
-                    !$bNoOptimize, $bProfile, $iScale, $strTimeZone, !$bNoDebug, $bDebugTestTrace,
+                    $oStorageTest, $strBackRestBase, $strTestPath, $$oyTestRun[$iTestIdx], $bDryRun, $bVmOut, $strPlatform,
+                    $strImage, $iVmIdx, $iVmMax, $strMakeCmd, $iTestIdx, $iTestMax, $strLogLevel, $strLogLevelTest,
+                    $strLogLevelTestFile, !$bNoLogTimestamp, $bShowOutputAsync, $bNoCleanup, $iRetry, !$bNoBackTrace, !$bNoValgrind,
+                    !$bNoCoverage, $bCoverageSummary, !$bNoOptimize, $bProfile, $iScale, $strTimeZone, !$bNoDebug, $bDebugTestTrace,
                     $iBuildMax / $iVmMax < 1 ? 1 : int($iBuildMax / $iVmMax));
                 $iTestIdx++;
 
